@@ -7,14 +7,15 @@ using namespace Rcpp;
 
 /******************************************************************************/
 
-#define CALL_PMATVEC4(ACC) return bigstatsr::pMatVec4(ACC, x);
+#define CALL_PMATVEC4(ACC) return bigstatsr::pMatVec4(ACC, x, ncores);
 
 // Dispatch function for pMatVec4
 // [[Rcpp::export]]
 NumericVector pMatVec4(Environment BM,
                        const NumericVector& x,
                        const IntegerVector& rowInd,
-                       const IntegerVector& colInd) {
+                       const IntegerVector& colInd,
+                       int ncores) {
 
   myassert_size(colInd.size(), x.size());
 
@@ -23,14 +24,15 @@ NumericVector pMatVec4(Environment BM,
 
 /******************************************************************************/
 
-#define CALL_CPMATVEC4(ACC) return bigstatsr::cpMatVec4(ACC, x);
+#define CALL_CPMATVEC4(ACC) return bigstatsr::cpMatVec4(ACC, x, ncores);
 
 // Dispatch function for cpMatVec4
 // [[Rcpp::export]]
 NumericVector cpMatVec4(Environment BM,
                         const NumericVector& x,
                         const IntegerVector& rowInd,
-                        const IntegerVector& colInd) {
+                        const IntegerVector& colInd,
+                        int ncores) {
 
   myassert_size(rowInd.size(), x.size());
 
